import greenfoot.*;

/**
 * The thing you control by your keyboard, to send the ball to different directions.
 * You can only move it left and right, and you can't move it further than
 * the edges of the world.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class Paddle extends GameObject
{
    private Player ball;
    private Message descrText;
    
    /**
     * What the paddle must do when it is added to the world:
     * create a new ball.
     */
    public void addedToWorld(World world)
    {
        newBall();
    }
    
    /**
     * Watch for presses on the keyboard and move.
     */
    public void act()
    {
        if (getWorld() == null) return;
        if (isPaused()) return;
        if (getX() >= getImage().getWidth() /2 && Greenfoot.isKeyDown ("left")) {
            moveSideways(-6);
        }
        if (getX() <= getWorld().getWidth() -getImage().getWidth() /2 && Greenfoot.isKeyDown ("right")) {
            moveSideways(6);
        }
        if (haveBall() && Greenfoot.isKeyDown ("space")) {
            releaseBall();
        }
    }
    
    private void moveSideways(int dist)
    {
        setLocation (getX() + dist, getY());
        if (this.ball != null) {
            this.ball.move (dist);
        }
    }
    
    /**
     * Creates a new ball on the paddle: the old one won't get removed
     * by this method.
     */
    public void newBall()
    {
        this.ball = new Player();
        getWorld().addObject(this.ball, getX(), getY()-20);
        
        this.descrText = new Message("Press space to start");
        this.descrText.showInWorld(getWorld());
    }
    
    /**
     * Returns the ball it has.
     * This will return null if it has no ball anymore.
     */
    public Player getBall()
    {
        return this.ball;
    }
    
    /**
     * Returns the paddle still has a ball on it or not.
     */
    public boolean haveBall()
    {
        return this.ball != null;
    }
    
    /**
     * Releases the ball.
     * From now on, the haveBall method will return false;
     */
    public void releaseBall()
    {
        this.ball.release();
        getWorld().removeObject(this.descrText);
        this.descrText = null;
        this.ball = null;
    }
}