import greenfoot.*;


/**
 * A button with a different appearance: a pause icon instead of text.
 * It doesn't create a pause menu itself, but it is meant to be used
 * with one.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class PauseButton extends Button
{
    private String title;
    
    /**
     * Constructor for objects of the class PauseButton.
     */
    public PauseButton()
    {
        this("");
    }
    
    /**
     * Constructor for objects of the class PauseButton.
     * @param titleTag The title of the pause button. You can
     * use this as a tag (so you can recognize it), but you don't
     * see it on screen.
     */
    public PauseButton(String titleTag)
    {
        this.title = titleTag;
        createImage();
    }
    
    private void createImage()
    {
        GreenfootImage img = new GreenfootImage(50, 50);
        img.setColor(Color.BLACK);
        img.fillOval(0, 0, img.getWidth(), img.getHeight());
        img.setColor(Color.GREEN);
        img.fillOval(4, 4, img.getWidth() -8, img.getHeight() -8);
        
        img.setColor(Color.BLUE);
        img.fillRect(img.getWidth() /2 -9, img.getHeight() /2 -10, 7, 20);
        img.fillRect(img.getWidth() /2 +4, img.getHeight() /2 -10, 7, 20);
        
        img.setTransparency(200);
        
        setImage(img);
    }
    
    /**
     * Returns the title of the button.
     */
    public String getTitle()
    {
        return title;
    }
    
    /**
     * Sets the title of the button.
     */
    public void setTitle(String newTitle)
    {
        if (!this.title.equals(newTitle)) {
            this.title = newTitle;
        }
    }
}