import greenfoot.*;
import java.util.List;

/**
 * This is the thing the player controls. It is moved by the paddle and it bounces
 * off the walls.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class Player extends GameObject
{
    private int deltaX;
    private int deltaY;
    private int count = 2;
    
    private boolean stuck;
    
    /**
     * Constructor for objects of the class Player.
     */
    public Player()
    {
        stuck = true;
        this.deltaX = Greenfoot.getRandomNumber(11) - 5;
        this.deltaY = Greenfoot.getRandomNumber(11) - 5;
    }
    
    /**
     * Let the player move and add some smoke effects.
     */
    public void act() 
    {
        if (getWorld() == null) return;
        if (isPaused()) return;
        if (!stuck) {
            move();
            checkBalls();
            checkPaddle();
            checkWalls();
        }
    }
    
    /**
     * Move the ball. Then check whether we've hit a wall.
     */
    private void move()
    {
        setLocation(getX() + this.deltaX, getY() + this.deltaY);
    }
    
    /**
     * Check whether we've hit one of the walls. Reverse direction if necessary.
     */
    private void checkWalls()
    {
        if (getY() >= getWorld().getHeight() -1) {
            ((GameWorld) getWorld()).gameOver(this);
            return;
        }
        if (getX() == 0 || getX() == getWorld().getWidth()-1) {
            this.deltaX = -this.deltaX;
        }
        if (getY() == 0 || getY() == getWorld().getHeight()-1) {
            this.deltaY = -this.deltaY;
        }
    }
    
    /**
     * Put out a puff of smoke (only on every second call).
     */
   
    /**
     * Looks for a ball on screen, and score points if it sees one.
     */
    private void checkBalls()
    {
        List<Ball> balls = getObjectsInRange(getImage().getWidth(), Ball.class);
        if (!balls.isEmpty()) {
            for (Ball ball : balls) {
                if (getWorld() instanceof GameWorld) {
                    ((GameWorld) getWorld()).addScore(ball.getPoints());
                    ((GameWorld) getWorld()).ballEaten();
                }
                getWorld().removeObject(ball);
                this.deltaY = -this.deltaY;
            }
        }
    }
    
    /**
     * Looks for a padle, and bounce off it when it sees one.
     */
    public void checkPaddle()
    {
        Actor paddle = getOneIntersectingObject(Paddle.class);
        if (paddle != null) {
            this.deltaY = -this.deltaY;
            int offset = getX() - paddle.getX();
            this.deltaX = this.deltaX + (offset/10);
            if (this.deltaX > 7) {
                this.deltaX = 7;
            }
            if (this.deltaX < -7) {
                this.deltaX = -7;
            }
        }
    }
    
    /**
     * Release the ball from the paddle.
     */
    public void release()
    {
        this.deltaX = Greenfoot.getRandomNumber(11) - 5;
        this.deltaY = -5;
        stuck = false;
    }
}