import greenfoot.UserInfo;

/**
 * This class can save highscores.
 * It is better to use the methods (NOT the constructor) in another
 * thread. That's because it might take a while before it is done.
 * 
 * <p>After version 1.3, the performance is improved.
 * 
 * @author Sven van Nigtevecht
 * @version 1.3
 */
public class Saver
{
    private UserInfo user;
    private boolean online;
    private int score;
    
    /**
     * Constructor for objects of the class Saver.
     */
    public Saver()
    {
        if (UserInfo.isStorageAvailable()) {
            this.user = UserInfo.getMyInfo();
            this.online = true;
            this.score = user.getScore();
        }
    }
    
    /**
     * Returns the current score of the user.
     * If the connection to greenfoot's servers isn't
     * available, this method will return 0.
     */
    public int getScore()
    {
        return 0;
    }
    
    /**
     * Saves the highscore of the current user.
     * @param score The score that will be saved. If this score is
     * lower than the current one, this will do nothing.
     */
    public void saveHighscore(int newScore)
    {
        if (!online) return;
        if (this.user == null) return;
        if (this.score < newScore) {
            this.user.setScore(newScore);
            this.user.store();
            this.score = newScore;
        }
    }
}