import greenfoot.World;

/**
 * The thing which loads a scoreboard. It also puts up a little message for
 * the user, so he/she knows what it happening.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class ScoreBoardThread implements Runnable
{
    private World world;
    private Saver saver;
    private int score;
    
    /**
     * Constructor for objects of the class ScoreBoardThread.
     * Fill in null for the saver parameter if you don't want to save.
     */
    public ScoreBoardThread(World world, Saver saver, int score)
    {
        this.world = world;
        this.saver = saver;
        this.score = score;
    }
    
    /**
     * This represents what the thread must do: load the scoreboard.
     * It also saves a score, if you didn't give saver a null value
     * in the constructor.
     */
    public void run()
    {
        if (saver != null) {
            Message m = new Message("Saving your score, please wait...");
            m.showInWorld(this.world);
            this.saver.saveHighscore(this.score);
            this.world.removeObject(m);
        }
        
        Message m = new Message("Loading highscores, please wait...");
        m.showInWorld(this.world);
        
        ScoreBoard sb = new ScoreBoard(this.world.getWidth(), this.world.getHeight() -50);
        this.world.addObject(sb, this.world.getWidth() /2, this.world.getHeight() /2 -52);
        this.world.removeObject(m);
    }
}