import greenfoot.*;


/**
 * A more primitive way to present text on the screen. It is good for showing titles
 * or something else, but use the Message class for real messages for the user.
 * 
 * @author Sven van Nigtevecht 
 * @version 1.0
 */
public class Text extends Actor
{
    private String text;
    private int height;
    private Color color;
    
    /**
     * This creates a text with a standard height and a black color.
     * @param theText The text you want to display on the screen.
     */
    public Text(String theText)
    {
        this(theText, 20, new Color(0, 0, 0));
    }
    
    /**
     * This creates a new text with a black color.
     * @param theText The text you will see in the world.
     * @param textHeight The height of the text.
     */
    public Text(String theText, int textHeight)
    {
        this(theText, textHeight, new Color(0, 0, 0));
    }
    
    /**
     * This creates a new text.
     * @param theText The text you will see in the world.
     * @param height The height of the text
     * @param textColor The color of the text.
     * You need to import java.awt.Color in the class which creates the text.
     */
    public Text(String theText, int textHeight, Color textColor)
    {
        text = theText;
        height = textHeight;
        color = textColor;
        
        GreenfootImage gambar = getImage();
        gambar.setColor(Color.BLUE);
        setImage(gambar);
    }
    
    /**
     * Make the text on the screen.
     */
    private void updateImage()
    {
        GreenfootImage gambar = getImage();
        gambar.clear();
        //gambar.drawString(teks + nilai, 1, 12);
    }
    
    /**
     * Change the text.
     * @param newText The text the current text will be replaced with.
     */
    public void setText(String newText)
    {
        text = newText;
        updateImage();
    }
    
    /**
     * Change the height of the text.
     * @param newHeight The new height of the text.
     */
    public void setHeight(int newHeight)
    {
        height = newHeight;
        updateImage();
    }
    
    /**
     * Change the color of the text.
     * @param newColor The new color of the text. You need to import java.awt.Color to use this.
     */
    public void setColor(Color newColor)
    {
        color = newColor;
        updateImage();
    }
}